==> streampipes-config-0.55.2-sources.jar: org/streampipes/config/model/ConfigItem.java <==
/*
 * Copyright 2018 FZI Forschungszentrum Informatik
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.streampipes.config.model;

public class ConfigItem {

    private String key;
    private String description;
    private String value;
    private String valueType;
    private boolean isPassword;

    public ConfigItem() {
        setPassword(false);
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public String getValueType() {
        return valueType;
    }

    public void setValueType(String valueType) {
        this.valueType = valueType;
    }

    public boolean isPassword() {
        return isPassword;
    }

    public void setPassword(boolean state) {
        isPassword = state;
    }
}

==> streampipes-config-0.65.0-sources.jar: org/streampipes/config/model/ConfigItem.java <==
/*
 * Copyright 2018 FZI Forschungszentrum Informatik
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.streampipes.config.model;

public class ConfigItem {

    private String key;
    private String description;
    private String value;
    private String valueType;
    private ConfigurationScope configurationScope;
    private boolean isPassword;

    public ConfigItem() {
        setPassword(false);
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public String getValueType() {
        return valueType;
    }

    public void setValueType(String valueType) {
        this.valueType = valueType;
    }

    public boolean isPassword() {
        return isPassword;
    }

    public void setPassword(boolean state) {
        isPassword = state;
    }

    public ConfigurationScope getConfigurationScope() {
        return configurationScope;
    }

    public void setConfigurationScope(ConfigurationScope configurationScope) {
        this.configurationScope = configurationScope;
    }
}
